<?php
/**
 * @file
 * Theme setting callbacks for the nucleus theme.
 */
include_once(drupal_get_path('theme', 'pinteros') . '/common.inc');

function pinteros_reset_settings() {
  global $theme_key;
  variable_del('theme_' . $theme_key . '_settings');
  variable_del('theme_settings');
  $cache = &drupal_static('theme_get_setting', array());
  $cache[$theme_key] = NULL;
}

function pinteros_form_system_theme_settings_alter(&$form, $form_state) {
  if (theme_get_setting('pinteros_use_default_settings')) {
    pinteros_reset_settings();
  }
  $form['#attached']['js'][] = array(
    'data' => drupal_get_path('theme', 'pinteros') . '/js/weebpal.js',
    'type' => 'file',
  );
  $form['pinteros']['pinteros_version'] = array(
    '#type' => 'hidden',
    '#default' => '1.0',
  );
  pinteros_settings_layout_tab($form);
  pinteros_feedback_form($form);
  $form['#submit'][] = 'pinteros_form_system_theme_settings_submit';
}

function pinteros_settings_layout_tab(&$form) {
  global $theme_key;
  $skins = pinteros_get_predefined_param('skins', array('' => t("Default skin")));
  $form['pinteros']['settings'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#title' => t('Settings'),
    '#weight' => 0,
  );

  $form['pinteros']['settings']['layout_configs'] = array(
    '#type' => 'fieldset',
    '#title' => t('Layout Configs'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['pinteros']['settings']['layout_configs']['pinteros_display'] = array(
    '#type' => 'select',
    '#title' => t('Pinteros Display'),
    '#default_value' => theme_get_setting('pinteros_display'),
    '#options' => array(
      'bootstrap-default-display' => t("Bootstrap Default"),
      'pinteros-fullwidth-display' => t("Full Width"),
    )
  );

  if (count($skins) > 1) {
    $form['pinteros']['settings']['layout_configs']['skin'] = array(
      '#type' => 'select',
      '#title' => t('Skin'),
      '#default_value' => theme_get_setting('skin'),
      '#options' => $skins,
    );
  }

  $form['pinteros']['settings']['layout_configs']['sidebar_first_width'] = array(
    '#type' => 'select',
    '#title' => t('Sidebar First Width'),
    '#default_value' => theme_get_setting('sidebar_first_width'),
    '#options' => array(
      0 => '0 column',
      1 => '1 column',
      2 => '2 columns',
      3 => '3 columns',
      4 => '4 columns',
      5 => '5 columns',
      6 => '6 columns',
    ),
  );
  
  $form['pinteros']['settings']['layout_configs']['sidebar_second_width'] = array(
    '#type' => 'select',
    '#title' => t('Sidebar Second Width'),
    '#default_value' => theme_get_setting('sidebar_second_width'),
    '#options' => array(
      0 => '0 column',
      1 => '1 column',
      2 => '2 columns',
      3 => '3 columns',
      4 => '4 columns',
      5 => '5 columns',
      6 => '6 columns',
    ),
  );
  
  $form['theme_settings']['toggle_logo']['#default_value'] = theme_get_setting('toggle_logo');
  $form['theme_settings']['toggle_name']['#default_value'] = theme_get_setting('toggle_name');
  $form['theme_settings']['toggle_slogan']['#default_value'] = theme_get_setting('toggle_slogan');
  $form['theme_settings']['toggle_node_user_picture']['#default_value'] = theme_get_setting('toggle_node_user_picture');
  $form['theme_settings']['toggle_comment_user_picture']['#default_value'] = theme_get_setting('toggle_comment_user_picture');
  $form['theme_settings']['toggle_comment_user_verification']['#default_value'] = theme_get_setting('toggle_comment_user_verification');
  $form['theme_settings']['toggle_favicon']['#default_value'] = theme_get_setting('toggle_favicon');
  $form['theme_settings']['toggle_secondary_menu']['#default_value'] = theme_get_setting('toggle_secondary_menu');
  $form['theme_settings']['show_skins_menu'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show Skins Menu'),
    '#default_value' => theme_get_setting('show_skins_menu'),
  );

  $form['logo']['default_logo']['#default_value'] = theme_get_setting('default_logo');
  $form['logo']['settings']['logo_path']['#default_value'] = theme_get_setting('logo_path');
  $form['favicon']['default_favicon']['#default_value'] = theme_get_setting('default_favicon');
  $form['favicon']['settings']['favicon_path']['#default_value'] = theme_get_setting('favicon_path');
  $form['theme_settings']['#collapsible'] = TRUE;
  $form['theme_settings']['#collapsed'] = FALSE;
  $form['logo']['#collapsible'] = TRUE;
  $form['logo']['#collapsed'] = FALSE;
  $form['favicon']['#collapsible'] = TRUE;
  $form['favicon']['#collapsed'] = FALSE;
  $form['pinteros']['settings']['theme_settings'] = $form['theme_settings'];
  $form['pinteros']['settings']['logo'] = $form['logo'];
  $form['pinteros']['settings']['favicon'] = $form['favicon'];

  unset($form['theme_settings']);
  unset($form['logo']);
  unset($form['favicon']);

  $form['pinteros']['pinteros_use_default_settings'] = array(
    '#type' => 'hidden',
    '#default_value' => 0,
  );
  $form['actions']['pinteros_use_default_settings_wrapper'] = array(
    '#markup' => '<input type="submit" value="' . t('Reset theme settings') . '" class="form-submit form-reset" onclick="return Drupal.Light.onClickResetDefaultSettings();" style="float: right;">',
  );  
}

function pinteros_feedback_form(&$form) {
  $form['pinteros']['about_pinteros'] = array(
    '#type' => 'fieldset',
    '#title' => t('Feedback Form'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#weight' => 40,
  );

  $form['pinteros']['about_pinteros']['about_pinteros_wrapper'] = array(
    '#type' => 'container',
    '#attributes' => array('class' => array('about-pinteros-wrapper')),
  );

  $form['pinteros']['about_pinteros']['about_pinteros_wrapper']['about_pinteros_content'] = array(
    '#markup' => '<iframe width="100%" height="650" scrolling="no" class="nucleus_frame" frameborder="0" src="http://www.weebpal.com/static/feedback/"></iframe>',
  );
}

function pinteros_form_system_theme_settings_submit($form, &$form_state) {
  if(isset($form_state['input']['skin']) && $form_state['input']['skin'] != $form_state['complete form']['pinteros']['settings']['layout_configs']['skin']['#default_value']) {
    setcookie('pinteros_skin', $form_state['input']['skin'], time() + 100000, base_path());
  }
}
